@@ -3,11 +3,12 @@ from pathlib import Path
 from unittest import mock
 from unittest.mock import MagicMock
 
+from bx_py_utils.auto_doc import assert_readme_block
 from bx_py_utils.path import assert_is_file
 from bx_py_utils.test_utils.snapshot import assert_text_snapshot
 
 import manageprojects
-from manageprojects import __version__
+from manageprojects import __version__, constants
 from manageprojects.cli import cli_app
 from manageprojects.cli.cli_app import cli, start_project, update_project
 from manageprojects.data_classes import CookiecutterResult
@@ -17,6 +18,19 @@ from manageprojects.tests.base import BaseTestCase
 
 PACKAGE_ROOT = Path(manageprojects.__file__).parent.parent
 assert_is_file(PACKAGE_ROOT / 'pyproject.toml')
+README_PATH = PACKAGE_ROOT / 'README.md'
+assert_is_file(README_PATH)
+
+
+def assert_cli_help_in_readme(text_block: str, marker: str):
+    text_block = text_block.replace(constants.CLI_EPILOG, '')
+    text_block = f'```\n{text_block.strip()}\n```'
+    assert_readme_block(
+        readme_path=README_PATH,
+        text_block=text_block,
+        start_marker_line=f'[comment]: <> (✂✂✂ auto generated {marker} start ✂✂✂)',
+        end_marker_line=f'[comment]: <> (✂✂✂ auto generated {marker} end ✂✂✂)',
+    )
 
 
 class CliTestCase(BaseTestCase):
@@ -29,9 +43,11 @@ class CliTestCase(BaseTestCase):
                 'Usage: ./cli.py [OPTIONS] COMMAND [ARGS]...',
                 'start-project',
                 'update-project',
+                constants.CLI_EPILOG,
             ),
         )
         assert_text_snapshot(got=stdout)
+        assert_cli_help_in_readme(text_block=stdout, marker='main help')
 
     def test_start_project_help(self):
         stdout = invoke_click(cli, 'start-project', '--help')
@@ -44,6 +60,7 @@ class CliTestCase(BaseTestCase):
             ),
         )
         assert_text_snapshot(got=stdout)
+        assert_cli_help_in_readme(text_block=stdout, marker='start-project help')
 
     def test_start_project_cli(self):
         result = CookiecutterResult(
@@ -91,6 +108,7 @@ class CliTestCase(BaseTestCase):
             ),
         )
         assert_text_snapshot(got=stdout)
+        assert_cli_help_in_readme(text_block=stdout, marker='update-project help')
 
     def test_update_project_cli(self):
         tempdir = tempfile.gettempdir()
